<?php

namespace Cart\Refund\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Cart\Refund\Http\Requests\RefundRequest;
use Cart\Refund\Models\Refund;

/**
 * Admin web controller class.
 */
class RefundWorkflowController extends BaseController
{

    /**
     * Workflow controller function for refund.
     *
     * @param Model   $refund
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(RefundRequest $request, Refund $refund, $step)
    {

        try {

            $refund->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('refund::refund.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/refund/refund/' . $refund->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/refund/refund/' . $refund->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for refund.
     *
     * @param Model   $refund
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Refund $refund, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $refund->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('refund::refund.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('refund::admin.refund.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('refund::admin.refund.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('refund::admin.refund.message', $data)->render();

        }

    }
}
