<?php

namespace Cart\Refund\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Cart\Refund\Models\Refund;

class RefundAction
{
    /**
     * Perform the complete action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */
    public function complete(Refund $refund)
    {
        try {
            $refund->status = 'complete';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */public function verify(Refund $refund)
    {
        try {
            $refund->status = 'verify';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */public function approve(Refund $refund)
    {
        try {
            $refund->status = 'approve';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */public function publish(Refund $refund)
    {
        try {
            $refund->status = 'publish';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */
    public function archive(Refund $refund)
    {
        try {
            $refund->status = 'archive';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Refund $refund
     *
     * @return Refund
     */
    public function unpublish(Refund $refund)
    {
        try {
            $refund->status = 'unpublish';
            return $refund->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
