<?php

namespace Cart\Refund\Workflow;

use Cart\Refund\Models\Refund;
use Validator;

class RefundValidator
{

    /**
     * Determine if the given refund is valid for complete status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function complete(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given refund is valid for verify status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function verify(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given refund is valid for approve status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function approve(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given refund is valid for publish status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function publish(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given refund is valid for archive status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function archive(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given refund is valid for unpublish status.
     *
     * @param Refund $refund
     *
     * @return bool / Validator
     */
    public function unpublish(Refund $refund)
    {
        return Validator::make($refund->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
